@@ -31,6 +31,7 @@ config = {
     'cluster_host': os.getenv('CLUSTER_HOST'),
     'cluster_id': os.getenv('CLUSTER_ID'),
     'sql_statements': os.getenv('SQL_STATEMENTS'),
+    'boto_session': None
 }
 
 logger = logging.getLogger('redshift_query')
@@ -45,10 +46,15 @@ def set_config(new_config):
 def query(event, context=None):
     logger.debug('Passed Event: %s', event)
 
-    client = boto3.client('redshift')
-
     this_config = {**config, **event}
 
+    session = this_config['boto_session'] or boto3.session.Session()
+
+    if not isinstance(session, boto3.session.Session):
+        raise RuntimeError('Not a valid boto3 session. Please check your configuration')
+
+    client = session.client('redshift')
+
     logger.debug('Passed this_config with added defaults: %s', this_config)
 
     credentials = client.get_cluster_credentials(
@@ -61,11 +67,12 @@ def query(event, context=None):
     logger.debug('Received Credentials')
 
     db = pg.DB(f"host={this_config['cluster_host']} "
-                      f"dbname={this_config['db_name']} "
-                      f"user={credentials['DbUser']} "
-                      f"password={credentials['DbPassword']} "
-                      'port=5439 '
-                      'keepalives=1 keepalives_idle=200 keepalives_interval=200 keepalives_count=6 connect_timeout=10')
+               f"dbname={this_config['db_name']} "
+               f"user={credentials['DbUser']} "
+               f"password={credentials['DbPassword']} "
+               'port=5439 '
+               'keepalives=1 keepalives_idle=200 keepalives_interval=200 keepalives_count=6 '
+               'connect_timeout=10')
 
     logger.debug('Connected')
 
